==> ejc-zatopbpm-impl-3.0.0-20230918.100108-18-sources.jar: com/ejianc/zatopbpm/bean/ErrorCallbackEntity.java <==
package com.ejianc.zatopbpm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 错误回调事件实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_error_callback")
public class ErrorCallbackEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_id")
    private Long billId; // 单据id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="type")
    private String type; // 错误的类型
    @TableField(value="userid")
    private String userid; // 用户编码
    @TableField(value="param")
    private String param; // 参数信息
    @TableField(value="message")
    private String message; // 错误信息
    @TableField(value="state")
    private String state; // 处理状态

    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }

    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public ErrorCallbackEntity() {

    }

    public ErrorCallbackEntity(Long billId, String billTypeCode, String type, String userid, String param, String message) {
        this.billId = billId;
        this.billTypeCode = billTypeCode;
        this.type = type;
        this.userid = userid;
        this.param = param;
        this.message = message;
        this.state = "未处理";
    }

}

==> ejc-zatopbpm-impl-3.0.0-20231012.032030-70-sources.jar: com/ejianc/zatopbpm/bean/ErrorCallbackEntity.java <==
package com.ejianc.zatopbpm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 错误回调事件实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_error_callback")
public class ErrorCallbackEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_id")
    private Long billId; // 单据id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="type")
    private String type; // 错误的类型
    @TableField(value="userid")
    private String userid; // 用户编码
    @TableField(value="param")
    private String param; // 参数信息
    @TableField(value="message")
    private String message; // 错误信息
    @TableField(value="state")
    private String state; // 处理状态
    @TableField(value="bpm_id")
    private String bpmId; // 审批id

    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }

    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getBpmId() {
        return bpmId;
    }

    public void setBpmId(String bpmId) {
        this.bpmId = bpmId;
    }

    public ErrorCallbackEntity() {

    }

    public ErrorCallbackEntity(Long billId, String billTypeCode, String type, String userid, String param, String message, String bpmId) {
        this.billId = billId;
        this.billTypeCode = billTypeCode;
        this.type = type;
        this.userid = userid;
        this.param = param;
        this.message = message;
        this.bpmId = bpmId;
        this.state = "未处理";
    }
}
